<?php
/**
 * Elusive controller
 *
 * @package Spam Master
 */

/**
 * Main elusive class.
 *
 * @since 6.0.0
 */
class SpamMasterElusiveController {

	/**
	 * Variable spam_elusive.
	 *
	 * @var spam_elusive $spam_elusive
	 **/
	protected $spam_elusive;

	/**
	 * Spam master elusive.
	 *
	 * @param spam_elusive $spam_elusive for collection.
	 *
	 * @return string
	 */
	public function spammasterelusive( $spam_elusive ) {

		// Ajax time.
		if ( isset( $spam_elusive['time'] ) ) {

			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			$bail = 'bail';
			return $bail;
		}
		// Woocommerce, EDD, others without action key.
		if ( isset( $spam_elusive['product_id'] ) || isset( $spam_elusive['add-to-cart'] ) || isset( $spam_elusive['security'] ) || isset( $spam_elusive['woocommerce-cart-nonce'] ) || isset( $spam_elusive['woocommerce-process-checkout-nonce'] ) || isset( $spam_elusive['woocommerce-login-nonce'] ) || isset( $spam_elusive['edd_license_key'] ) || isset( $spam_elusive['wpp_id'] ) ) {

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			$bail = 'bail';
			return $bail;
		}
		// Several plugins via action name.
		if ( isset( $spam_elusive['action'] ) ) {
			$spam_action_array = array(
				'alg_wc_eu_vat_validate_action',
				'borlabs_cookie_handler',
				'check_privacy_setting',
				'check_privacy_settings',
				'checkout_login',
				'crontrol_checkhash',
				'dokan_pageview',
				'edd_add_to_cart',
				'edd_apply_discount',
				'edd_process_checkout',
				'edd_vat_validate',
				'eventon_init_load',
				'feed_locator',
				'heartbeat',
				'icegram_event_track',
				'load_fragments',
				'pisol_product_estimate',
				'porto_lazyload_menu',
				'post_counter',
				'pys_api_event',
				'sgpb_send_to_open_counter',
				'vc_get_vc_grid_data',
				'wpdLoadMoreComments',
			);
			if ( in_array( $spam_elusive['action'], $spam_action_array, true ) ) {

				// Spam Buffer Controller.
				$spam_master_buffer_controller = new SpamMasterBufferController();
				$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

				$bail = 'bail';
				return $bail;
			}
		}

		// Final check should always bail var.
		if ( preg_grep( '/[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})/i', $spam_elusive ) ) {

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			$matches = preg_grep( '/[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})/i', $spam_elusive );
			if ( $matches ) {
				foreach ( $matches as $key => $val ) {
					if ( filter_var( $val, FILTER_VALIDATE_EMAIL ) ) {
						$bail = wp_strip_all_tags( substr( $val, 0, 256 ) );
						return $bail;
					} else {
						$bail = 'haf@' . wp_rand( 10000000, 99999999 ) . '.wp';
						return $bail;
					}
				}
			} else {
				$bail = 'haf@' . wp_rand( 10000000, 99999999 ) . '.wp';
				return $bail;
			}
		} else {

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			$bail = 'haf@' . wp_rand( 10000000, 99999999 ) . '.wp';
			return $bail;
		}
	}

	/**
	 * Spam master json check.
	 *
	 * @param spam_elusive $spam_elusive for collection.
	 *
	 * @return bail|false
	 */
	public function spammasterisjson( $spam_elusive ) {

		if ( is_string( $spam_elusive ) && is_array( json_decode( $spam_elusive, true ) ) && ( json_last_error() === JSON_ERROR_NONE ) ) {

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			// Decode json.
			$spam_elusive_decoded = json_decode( $spam_elusive, true );

			foreach ( $spam_elusive_decoded as $prop => $val ) {
				$matches = preg_grep( '/^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$/', $val );
				if ( $matches ) {
					foreach ( $matches as $key => $val ) {
						$bail = $val;
					}
				} else {
					$bail = 'bail';
				}
			}
		} else {

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			$bail = 'bail';

		}
		return $bail;
	}

}
