<?php
/**
 * Honey controller
 *
 * @package Spam Master
 */

/**
 * Main honey class.
 *
 * @since 6.0.0
 */
class SpamMasterHoneyController {

	/**
	 * Variable remote_ip.
	 *
	 * @var remote_ip $remote_ip
	 **/
	protected $remote_ip;

	/**
	 * Variable blog_threat_email.
	 *
	 * @var blog_threat_email $blog_threat_email
	 **/
	protected $blog_threat_email;

	/**
	 * Variable remote_referer.
	 *
	 * @var remote_referer $remote_referer
	 **/
	protected $remote_referer;

	/**
	 * Variable dest_url.
	 *
	 * @var dest_url $dest_url
	 **/
	protected $dest_url;

	/**
	 * Variable remote_agent.
	 *
	 * @var remote_agent $remote_agent
	 **/
	protected $remote_agent;

	/**
	 * Variable spamuser_a.
	 *
	 * @var spamuser_a $spamuser_a
	 **/
	protected $spamuser_a;

	/**
	 * Variable mothers_name.
	 *
	 * @var mothers_name $mothers_name
	 **/
	protected $mothers_name;

	/**
	 * Variable mothers_last_name.
	 *
	 * @var mothers_last_name $mothers_last_name
	 **/
	protected $mothers_last_name;

	/**
	 * Variable trigger_s.
	 *
	 * @var trigger_s $trigger_s
	 **/
	protected $trigger_s;

	/**
	 * Variable spam_master_page.
	 *
	 * @var spam_master_page $spam_master_page
	 **/
	protected $spam_master_page;

	/**
	 * Spam master honey.
	 *
	 * @param remote_ip         $remote_ip for scan.
	 * @param blog_threat_email $blog_threat_email for scan.
	 * @param remote_referer    $remote_referer for scan.
	 * @param dest_url          $dest_url for scan.
	 * @param remote_agent      $remote_agent for scan.
	 * @param spamuser_a        $spamuser_a for scan.
	 * @param mothers_name      $mothers_name for scan.
	 * @param mothers_last_name $mothers_last_name for scan.
	 * @param spam_master_page  $spam_master_page for scan.
	 *
	 * @return void
	 */
	public function spammasterhoney( $remote_ip, $blog_threat_email, $remote_referer, $dest_url, $remote_agent, $spamuser_a, $mothers_name, $mothers_last_name, $spam_master_page ) {
		global $wpdb, $blog_id;

		// Add Table & Load Spam Master Options.
		if ( is_multisite() ) {
			$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
		} else {
			$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
		}
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_license_key = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_license_key'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_address = substr( $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_address'" ), 0, 256 );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_ip = substr( $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_ip'" ), 0, 48 );

		if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

			$spam_master_learn_h_url   = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2hvbmV5XzIucGhw';
			$spam_master_learning_post = array(
				'blog_license_key'    => $spam_license_key,
				'blog_threat_ip'      => $remote_ip,
				'blog_threat_user'    => $spamuser_a,
				'blog_threat_type'    => 'honeypot',
				'blog_threat_email'   => $blog_threat_email,
				'blog_threat_content' => 'Honeypot ' . $spam_master_page . ' Field 1: ' . $mothers_name . ', Field 2: ' . $mothers_last_name,
				'blog_threat_agent'   => $remote_agent,
				'blog_threat_refe'    => $remote_referer,
				'blog_threat_dest'    => $dest_url,
				'blog_web_adress'     => $spam_master_address,
				'blog_server_ip'      => $spam_master_ip,
			);

			$response = wp_remote_post(
				// phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.obfuscation_base64_decode
				base64_decode( $spam_master_learn_h_url ),
				array(
					'method'  => 'POST',
					'timeout' => 90,
					'body'    => $spam_master_learning_post,
				)
			);
			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				echo esc_attr( __( 'Something went wrong, please get in touch with Spam master Support: ', 'spam_master' ) . $error_message );
			} else {
				$data      = json_decode( wp_remote_retrieve_body( $response ), true );
				$remote_ip = $data['threat'];
				$spamc     = $data['c'];

				// Spam Buffer Controller.
				$blog_threat_email             = false;
				$spam_master_buffer_controller = new SpamMasterBufferController();
				$is_threat                     = $spam_master_buffer_controller->spammasterbufferinsert( $remote_ip, $blog_threat_email, $spamc );

				// Spam Buffer Controller.
				$spam_master_buffer_controller = new SpamMasterBufferController();
				$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

			}
		}
	}

	/**
	 * Spam master honey 2.
	 *
	 * @param remote_ip         $remote_ip for scan.
	 * @param blog_threat_email $blog_threat_email for scan.
	 * @param remote_referer    $remote_referer for scan.
	 * @param dest_url          $dest_url for scan.
	 * @param remote_agent      $remote_agent for scan.
	 * @param spamuser_a        $spamuser_a for scan.
	 * @param trigger_s         $trigger_s for scan.
	 * @param spam_master_page  $spam_master_page for scan.
	 *
	 * @return IS_HONEY2
	 */
	public function spammasterhoney2( $remote_ip, $blog_threat_email, $remote_referer, $dest_url, $remote_agent, $spamuser_a, $trigger_s, $spam_master_page ) {
		global $wpdb, $blog_id;

		// Add Table & Load Spam Master Options.
		if ( is_multisite() ) {
			$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
		} else {
			$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
		}
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_license_key = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_license_key'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_address = substr( $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_address'" ), 0, 256 );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_ip = substr( $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_ip'" ), 0, 48 );

		if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

			$spam_master_learn_h2_url  = 'aHR0cHM6Ly93d3cuc3BhbW1hc3Rlci5vcmcvd3AtY29udGVudC9wbHVnaW5zL3NwYW0tbWFzdGVyLWFkbWluaXN0cmF0b3IvaW5jbHVkZXMvbGVhcm5pbmcvZ2V0X2xlYXJuX2hvbmV5Ml8yLnBocA==';
			$spam_master_learning_post = array(
				'blog_license_key'    => $spam_license_key,
				'blog_threat_ip'      => $remote_ip,
				'blog_threat_user'    => $spamuser_a,
				'blog_threat_type'    => 'honeypot 2',
				'blog_threat_email'   => $blog_threat_email,
				'blog_threat_content' => 'Honeypot V2 ' . $spam_master_page . ' Triggered: ' . $trigger_s,
				'blog_threat_agent'   => $remote_agent,
				'blog_threat_refe'    => $remote_referer,
				'blog_threat_dest'    => $dest_url,
				'blog_web_adress'     => $spam_master_address,
				'blog_server_ip'      => $spam_master_ip,
			);

			$response = wp_remote_post(
				// phpcs:ignore WordPress.PHP.DiscouragedPHPFunctions.obfuscation_base64_decode
				base64_decode( $spam_master_learn_h2_url ),
				array(
					'method'  => 'POST',
					'timeout' => 90,
					'body'    => $spam_master_learning_post,
				)
			);
			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				echo esc_attr( __( 'Something went wrong, please get in touch with Spam master Support: ', 'spam_master' ) . $error_message );
			} else {
				$data = json_decode( wp_remote_retrieve_body( $response ), true );

				if ( empty( $data['threat'] ) ) {
					$nope = true;
				} else {
					$remote_ip = $data['threat'];
					$spamc     = $data['c'];

					// Spam Buffer Controller.
					$blog_threat_email             = false;
					$spam_master_buffer_controller = new SpamMasterBufferController();
					$is_threat                     = $spam_master_buffer_controller->spammasterbufferinsert( $remote_ip, $blog_threat_email, $spamc );

					// Spam Buffer Controller.
					$spam_master_buffer_controller = new SpamMasterBufferController();
					$is_buffer_count               = $spam_master_buffer_controller->spammasterbuffercount();

					return 'IS_HONEY2';
				}
			}
		}
	}

}

