<?php
/**
 * Load spam master honeypot.
 *
 * @package Spam Master
 */

global $wpdb, $blog_id;
// Add Table & Load Spam Master Options.
if ( is_multisite() ) {
	$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
} else {
	$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
}
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_honeypot_timetrap = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_honeypot_timetrap'" );
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_honeypot_timetrap_speed = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_honeypot_timetrap_speed'" );

if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

	if ( 'true' === $spam_master_honeypot_timetrap ) {
		// MULTISITE HOOKS.
		if ( is_multisite() ) {
			add_action( 'signup_extra_fields', 'spam_master_honeypot_register_field', 20 );
			add_filter( 'wpmu_validate_user_signup', 'spam_master_honeypot_register_errors_multi', 20 );
			add_action( 'comment_form_after_fields', 'spam_master_honeypot_register_field', 1 );
			add_action( 'comment_form_logged_in_after', 'spam_master_honeypot_register_field', 1 );
			add_filter( 'preprocess_comment', 'spam_master_verify_honey_comment_data', 10, 3 );
			add_filter( 'wpcf7_form_elements', 'spam_master_add_honeypot_to_form', 10, 1 );
			add_filter( 'wpcf7_spam', 'spam_master_contact_form_7_honeypot' );
		} else {
			// SINGLE SITE HOOKS.
			add_action( 'register_form', 'spam_master_honeypot_register_field' );
			add_action( 'login_form', 'spam_master_honeypot_register_field' );
			add_action( 'comment_form_after_fields', 'spam_master_honeypot_register_field', 1 );
			add_action( 'comment_form_logged_in_after', 'spam_master_honeypot_register_field', 1 );
			add_filter( 'registration_errors', 'spam_master_honeypot_register_single_errors', 10, 3 );
			add_filter( 'login_errors', 'spam_master_honeypot_login_single_errors', 11, 1 );
			add_filter( 'preprocess_comment', 'spam_master_verify_honey_comment_data', 10, 3 );
			add_filter( 'wpcf7_form_elements', 'spam_master_add_honeypot_to_form', 10, 1 );
			add_filter( 'wpcf7_spam', 'spam_master_contact_form_7_honeypot' );
		}

		/**
		 * Spam master honeypot fields.
		 *
		 * @return void
		 */
		function spam_master_honeypot_register_field() {
			global $wpdb, $blog_id;

			// Reversed Ip.
			if ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
				$reverse_ip = strrev( sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) ) ) . '.' . bin2hex( random_bytes( 12 ) );
			} else {
				$reverse_ip = 'RH 666';
			}
			?>
			<p class="spam-master-hidden">
			<label for="<?php echo esc_attr( $reverse_ip ); ?>" class="spam-master-hidden"><?php echo esc_attr( $reverse_ip ); ?><br>
			<input class="spam-master-hidden input" type="text" name="<?php echo esc_attr( $reverse_ip ); ?>" id="<?php echo esc_attr( $reverse_ip ); ?>" placeholder="<?php echo esc_attr( $reverse_ip ); ?>" autocomplete="off" value="<?php echo esc_attr( $reverse_ip ); ?>" />
			</label>
			</p>
			<p class="spam-master-hidden">
			<label for="mothers_name" class="spam-master-hidden"><?php echo esc_attr( __( 'Mother Name', 'spam_master' ) ); ?><br>
			<input class="spam-master-hidden input" type="text" name="mothers_name" id="mothers_name" placeholder="Mother Name" autocomplete="off" value="" />
			</label>
			</p>
			<p class="spam-master-hidden">
			<label for="mothers_last_name" class="spam-master-hidden"><?php echo esc_attr( __( 'Mother Last Name', 'spam_master' ) ); ?><br>
			<input class="spam-master-hidden input" type="text" name="mothers_last_name" id="mothers_last_name" placeholder="Mother Last Name" autocomplete="off" value="" />
			</label>
			</p>
			<?php
			if ( isset( $_SESSION['spam-master-token'] ) && ! empty( $_SESSION['spam-master-token'] ) ) {
				?>
			<p class="spam-master-hidden">
			<label for="spam-master-token" class="spam-master-hidden"><?php echo esc_attr( __( 'Spam Master Token', 'spam_master' ) ); ?><br>
			<input class="input" type="hidden" name="spam-master-token" id="spam-master-token" placeholder="Spam Master Token" autocomplete="off" value="<?php echo esc_attr( $_SESSION['spam-master-token'] ); ?>" />
			</label>
			</p>
				<?php
			}
			// END FIELD.
		}

		/**
		 * Spam master multi-site validation errors.
		 *
		 * @param result $result for honey.
		 *
		 * @return result
		 */
		function spam_master_honeypot_register_errors_multi( $result ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Registration';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'honey_bot';
			if ( ! empty( $result['user_email'] ) ) {
				if ( filter_var( $result['user_email'], FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $result['user_email'], 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<p class="error"><strong>SPAM MASTER</strong> ' . $spam_master_message . '</p>';
				exit();
			}

			// Check Fields.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['mothers_name'] ) || ! empty( $_POST['mothers_last_name'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_name'] ) || empty( $_POST['mothers_name'] ) ) {
					$mothers_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_name = wp_unslash( $_POST['mothers_name'] );
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_last_name'] ) || empty( $_POST['mothers_last_name'] ) ) {
					$mothers_last_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_last_name = wp_unslash( $_POST['mothers_last_name'] );
				}
				// Spam Honey Controller.
				$spam_master_honey_controller = new SpamMasterHoneyController();
				$is_honey                     = $spam_master_honey_controller->spammasterhoney( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $mothers_name, $mothers_last_name, $spam_master_page );
				if ( $is_honey ) {
					// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					echo '<p class="error"><strong>SPAM MASTER</strong> ' . $spam_master_message . '</p>';
					exit();
				} else {
					// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					echo '<p class="error"><strong>SPAM MASTER</strong> ' . $spam_master_message . '</p>';
					exit();
				}
			}
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! isset( $_SESSION['spam-master-token'] ) || empty( $_SESSION['spam-master-token'] ) || ! isset( $_POST['spam-master-token'] ) || empty( $_POST['spam-master-token'] ) ) {
				$trigger_s = 'S';
			} else {
				$trigger_s = false;
			}
			if ( 'S' === $trigger_s ) {
				// Spam White Controller.
				$spamtype                     = $spam_master_page;
				$spam_master_white_controller = new SpamMasterWhiteController();
				$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
				if ( ! empty( $is_spamadmin ) ) {
					$itis = true;
				} else {
					// Spam White Controller.
					$spamtype                     = $spam_master_page;
					$spam_master_white_controller = new SpamMasterWhiteController();
					$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
					if ( ! empty( $is_white ) ) {
						$itis = true;
					} else {
						// Spam Honey Controller.
						$spam_master_honey_controller = new SpamMasterHoneyController();
						$is_honey2                    = $spam_master_honey_controller->spammasterhoney2( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $trigger_s, $spam_master_page );
					}
				}
			}
			return $result;
			// End Honey multi validation.
		}

		/**
		 * Spam master single-site validation errors.
		 *
		 * @param errors               $errors for honey.
		 * @param sanitized_user_login $sanitized_user_login for honey.
		 * @param user_email           $user_email for honey.
		 *
		 * @return errors
		 */
		function spam_master_honeypot_register_single_errors( $errors, $sanitized_user_login, $user_email ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Registration';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'honey_bot';
			if ( ! empty( $user_email ) ) {
				if ( filter_var( $user_email, FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $user_email, 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				$errors->add( 'invalid_email', esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
				return $errors;
			}

			// Check Fields.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['mothers_name'] ) || ! empty( $_POST['mothers_last_name'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_name'] ) || empty( $_POST['mothers_name'] ) ) {
					$mothers_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_name = wp_unslash( $_POST['mothers_name'] );
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_last_name'] ) || empty( $_POST['mothers_last_name'] ) ) {
					$mothers_last_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_last_name = wp_unslash( $_POST['mothers_last_name'] );
				}
				// Spam Honey Controller.
				$spam_master_honey_controller = new SpamMasterHoneyController();
				$is_honey                     = $spam_master_honey_controller->spammasterhoney( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $mothers_name, $mothers_last_name, $spam_master_page );
				if ( $is_honey ) {
					$errors->add( 'invalid_email', esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
					return $errors;
				} else {
					$errors->add( 'invalid_email', esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
					return $errors;
				}
			}
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! isset( $_SESSION['spam-master-token'] ) || empty( $_SESSION['spam-master-token'] ) || ! isset( $_POST['spam-master-token'] ) || empty( $_POST['spam-master-token'] ) ) {
				$trigger_s = 'S';
			} else {
				$trigger_s = false;
			}
			if ( 'S' === $trigger_s ) {
				// Spam White Controller.
				$spamtype                     = $spam_master_page;
				$spam_master_white_controller = new SpamMasterWhiteController();
				$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
				if ( ! empty( $is_spamadmin ) ) {
					$itis = true;
				} else {
					// Spam White Controller.
					$spamtype                     = $spam_master_page;
					$spam_master_white_controller = new SpamMasterWhiteController();
					$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
					if ( ! empty( $is_white ) ) {
						$itis = true;
					} else {
						// Spam Honey Controller.
						$spam_master_honey_controller = new SpamMasterHoneyController();
						$is_honey2                    = $spam_master_honey_controller->spammasterhoney2( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $trigger_s, $spam_master_page );
					}
				}
			}
			return $errors;
			// End Honey single validation.
		}

		/**
		 * Spam master single-site login validation errors.
		 *
		 * @param error $error for honey.
		 *
		 * @return error
		 */
		function spam_master_honeypot_login_single_errors( $error ) {
			global $wpdb, $blog_id, $errors, $user_email;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Login';

			// Spam Collect Controller.
			//
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			//
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'honey_bot';
			if ( ! empty( $user_email ) ) {
				if ( filter_var( $user_email, FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $user_email, 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				// phpcs:ignore WordPress.Security.NonceVerification.Recommended
				if ( ! empty( $_REQUEST['log'] ) ) {
					// phpcs:ignore WordPress.Security.NonceVerification.Recommended, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					if ( filter_var( wp_unslash( $_REQUEST['log'] ), FILTER_VALIDATE_EMAIL ) ) {
						// phpcs:ignore WordPress.Security.NonceVerification.Recommended, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
						$spampreemail = wp_strip_all_tags( substr( wp_unslash( $_REQUEST['log'] ), 0, 256 ) );
					} else {
						$spampreemail = false;
					}
				} else {
					$spampreemail = false;
				}
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				$error = '<strong>SPAM MASTER</strong>: ' . $spam_master_message;
			}

			// Check Fields.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['mothers_name'] ) || ! empty( $_POST['mothers_last_name'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_name'] ) || empty( $_POST['mothers_name'] ) ) {
					$mothers_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_name = wp_unslash( $_POST['mothers_name'] );
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_last_name'] ) || empty( $_POST['mothers_last_name'] ) ) {
					$mothers_last_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_last_name = wp_unslash( $_POST['mothers_last_name'] );
				}
				// Spam Honey Controller.
				$spam_master_honey_controller = new SpamMasterHoneyController();
				$is_honey                     = $spam_master_honey_controller->spammasterhoney( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $mothers_name, $mothers_last_name, $spam_master_page );
				if ( $is_honey ) {
					$error = '<strong>SPAM MASTER</strong>: ' . $spam_master_message;
				} else {
					$error = '<strong>SPAM MASTER</strong>: ' . $spam_master_message;
				}
			}
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! isset( $_SESSION['spam-master-token'] ) || empty( $_SESSION['spam-master-token'] ) || ! isset( $_POST['spam-master-token'] ) || empty( $_POST['spam-master-token'] ) ) {
				$trigger_s = 'S';
			} else {
				$trigger_s = false;
			}
			if ( 'S' === $trigger_s ) {

				// Spam White Controller.
				$spamtype                     = $spam_master_page;
				$spam_master_white_controller = new SpamMasterWhiteController();
				$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
				if ( ! empty( $is_spamadmin ) ) {
					$itis = true;
				} else {
					// Spam White Controller.
					$spamtype                     = $spam_master_page;
					$spam_master_white_controller = new SpamMasterWhiteController();
					$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
					if ( ! empty( $is_white ) ) {
						$itis = true;
					} else {
						// Spam Honey Controller.
						$spam_master_honey_controller = new SpamMasterHoneyController();
						$is_honey2                    = $spam_master_honey_controller->spammasterhoney2( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $trigger_s, $spam_master_page );
					}
				}
			}
			return $error;
			// End Honey single validation.
		}

		/**
		 * Spam master comment verification.
		 *
		 * @param commentdata $commentdata for honey.
		 *
		 * @return commentdata
		 */
		function spam_master_verify_honey_comment_data( $commentdata ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Comment';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'honey_bot';
			if ( ! empty( $commentdata['comment_author_email'] ) ) {
				if ( filter_var( $commentdata['comment_author_email'], FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $commentdata['comment_author_email'], 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Prepare Comment.
			if ( ! empty( $commentdata['comment_content'] ) ) {
				$result_comment_content_trim  = substr( $commentdata['comment_content'], 0, 360 );
				$result_comment_content_clean = wp_strip_all_tags( stripslashes_deep( $result_comment_content_trim ), true );
			} else {
				$result_comment_content_clean = 'empty';
			}

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				return wp_die( esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
			}

			// Check Fields.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['mothers_name'] ) || ! empty( $_POST['mothers_last_name'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_name'] ) || empty( $_POST['mothers_name'] ) ) {
					$mothers_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_name = wp_unslash( $_POST['mothers_name'] );
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_last_name'] ) || empty( $_POST['mothers_last_name'] ) ) {
					$mothers_last_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_last_name = wp_unslash( $_POST['mothers_last_name'] );
				}
				// Spam Honey Controller.
				$spam_master_honey_controller = new SpamMasterHoneyController();
				$is_honey                     = $spam_master_honey_controller->spammasterhoney( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $mothers_name, $mothers_last_name, $spam_master_page );
				if ( $is_honey ) {
					return wp_die( esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
				} else {
					return wp_die( esc_attr( __( 'SPAM MASTER: ', 'spam_master' ) . $spam_master_message ) );
				}
			}
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! isset( $_SESSION['spam-master-token'] ) || empty( $_SESSION['spam-master-token'] ) || ! isset( $_POST['spam-master-token'] ) || empty( $_POST['spam-master-token'] ) ) {
				$trigger_s = 'S';
			} else {
				$trigger_s = false;
			}
			if ( 'S' === $trigger_s ) {

				// Spam White Controller.
				$spamtype                     = $spam_master_page;
				$spam_master_white_controller = new SpamMasterWhiteController();
				$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
				if ( ! empty( $is_spamadmin ) ) {
					$itis = true;
				} else {
					// Spam White Controller.
					$spamtype                     = $spam_master_page;
					$spam_master_white_controller = new SpamMasterWhiteController();
					$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
					if ( ! empty( $is_white ) ) {
						$itis = true;
					} else {
						// Spam Honey Controller.
						$spam_master_honey_controller = new SpamMasterHoneyController();
						$is_honey2                    = $spam_master_honey_controller->spammasterhoney2( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $trigger_s, $spam_master_page );
					}
				}
			}
			return $commentdata;
		}

		/**
		 * Spam master contact form 7 fields.
		 *
		 * @param content $content for honey.
		 *
		 * @return content
		 */
		function spam_master_add_honeypot_to_form( $content ) {
			// Reversed Ip.
			if ( isset( $_SERVER['REMOTE_ADDR'] ) ) {
				$reverse_ip = strrev( sanitize_text_field( wp_unslash( $_SERVER['REMOTE_ADDR'] ) ) ) . '.' . bin2hex( random_bytes( 12 ) );
			} else {
				$reverse_ip = 'RH 666';
			}

			$content .= '<p class="spam-master-hidden">
						<label class="spam-master-hidden" for="' . $reverse_ip . '">' . $reverse_ip . '<br>
						<input class="spam-master-hidden input" type="text" name="' . $reverse_ip . '" id="' . $reverse_ip . '" autocomplete="off" value="' . $reverse_ip . '" />
						</label>
						</p>';
			$content .= '<p class="spam-master-hidden">
						<label class="spam-master-hidden" for="mothers_name">Mother Name<br>
						<input class="spam-master-hidden input" type="text" name="mothers_name" id="mothers_name" autocomplete="off" value="" />
						</label>
						</p>';
			$content .= '<p class="spam-master-hidden">
						<label class="spam-master-hidden" for="mothers_last_name">Mother Last Name<br>
						<input class="spam-master-hidden input" type="text" name="mothers_last_name" id="mothers_last_name" autocomplete="off" value="" />
						</label>
						</p>';
			if ( isset( $_SESSION['spam-master-token'] ) && ! empty( $_SESSION['spam-master-token'] ) ) {
				$content .= '<p class="spam-master-hidden">
							<label for="spam-master-token" class="spam-master-hidden">Spam Master Token<br>
							<input class="input" type="hidden" name="spam-master-token" id="spam-master-token" placeholder="Spam Master Token" autocomplete="off" value="' . wp_unslash( $_SESSION['spam-master-token'] ) . '" />
							</label>
							</p>';
			}
			return $content;
		}

		/**
		 * Spam master contact form 7 verification.
		 *
		 * @param spam $spam for honey.
		 *
		 * @return spam
		 */
		function spam_master_contact_form_7_honeypot( $spam ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Contact Form';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'honey_bot';
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['your-email'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( filter_var( wp_unslash( $_POST['your-email'] ), FILTER_VALIDATE_EMAIL ) ) {
					// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.NonceVerification.Missing
					$spampreemail = wp_strip_all_tags( substr( wp_unslash( $_POST['your-email'] ), 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Prepare Message.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['your-message'] ) ) {
				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.NonceVerification.Missing
				$result_comment_content_trim = substr( wp_unslash( $_POST['your-message'] ), 0, 360 );
				// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized, WordPress.Security.NonceVerification.Missing
				$result_comment_content_clean = wp_strip_all_tags( stripslashes_deep( $result_comment_content_trim ), true );
			} else {
				$result_comment_content_clean = 'your-message';
			}

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				// phpcs:ignore Squiz.PHP.DisallowMultipleAssignments.Found
				return $result['reason'] = array( 'spam' => wpcf7_get_message( 'spam' ) );
			}

			// Check Fields.
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! empty( $_POST['mothers_name'] ) || ! empty( $_POST['mothers_last_name'] ) ) {
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_name'] ) || empty( $_POST['mothers_name'] ) ) {
					$mothers_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_name = wp_unslash( $_POST['mothers_name'] );
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! isset( $_POST['mothers_last_name'] ) || empty( $_POST['mothers_last_name'] ) ) {
					$mothers_last_name = 'empty';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$mothers_last_name = wp_unslash( $_POST['mothers_last_name'] );
				}
				// Spam Honey Controller.
				$spam_master_honey_controller = new SpamMasterHoneyController();
				$is_honey                     = $spam_master_honey_controller->spammasterhoney( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $mothers_name, $mothers_last_name, $spam_master_page );
				if ( $is_honey ) {
					// phpcs:ignore Squiz.PHP.DisallowMultipleAssignments.Found
					return $result['reason'] = array( 'spam' => wpcf7_get_message( 'spam' ) );
				} else {
					// phpcs:ignore Squiz.PHP.DisallowMultipleAssignments.Found
					return $result['reason'] = array( 'spam' => wpcf7_get_message( 'spam' ) );
				}
			}
			// phpcs:ignore WordPress.Security.NonceVerification.Missing
			if ( ! isset( $_SESSION['spam-master-token'] ) || empty( $_SESSION['spam-master-token'] ) || ! isset( $_POST['spam-master-token'] ) || empty( $_POST['spam-master-token'] ) ) {
				$trigger_s = 'S';
			} else {
				$trigger_s = false;
			}
			if ( 'S' === $trigger_s ) {

				// Spam White Controller.
				$spamtype                     = $spam_master_page;
				$spam_master_white_controller = new SpamMasterWhiteController();
				$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
				if ( ! empty( $is_spamadmin ) ) {
					$itis = true;
				} else {
					// Spam White Controller.
					$spamtype                     = $spam_master_page;
					$spam_master_white_controller = new SpamMasterWhiteController();
					$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
					if ( ! empty( $is_white ) ) {
						$itis = true;
					} else {
						// Spam Honey Controller.
						$spam_master_honey_controller = new SpamMasterHoneyController();
						$is_honey2                    = $spam_master_honey_controller->spammasterhoney2( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $trigger_s, $spam_master_page );
					}
				}
			}
		}

		// end honeypot true.
	}
	// end valid.
}
