<?php
/**
 * Load spam master woo registration.
 *
 * @package Spam Master
 */

global $wpdb, $blog_id;
// Add Table & Load Spam Master Options.
if ( is_multisite() ) {
	$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
} else {
	$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
}
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );

if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

	/**
	 * Spam master woo validate extra fields.
	 *
	 * @param errors   $errors for validation.
	 * @param username $username for validation.
	 * @param password $password for validation.
	 * @param email    $email for validation.
	 *
	 * @return errors
	 * @throws Exception Exception.
	 */
	function spam_master_validate_woo_extra_validate_fields( $errors, $username, $password, $email ) {
		global $wpdb;

		// Add Table & Load Spam Master Options.
		if ( is_multisite() ) {
			$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
		} else {
			$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
		}
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

		// Spam Master page.
		$spam_master_page = 'Woocommerce';

		// Spam Collect Controller.
		$spam_master_collect_controller = new SpamMasterCollectController();
		$collect_now                    = true;
		$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

		// Spam User Controller.
		$spam_master_user_controller = new SpamMasterUserController();
		$spaminitial                 = 'woo';
		if ( ! empty( $email ) ) {
			if ( filter_var( $email, FILTER_VALIDATE_EMAIL ) ) {
				$spampreemail = wp_strip_all_tags( substr( $email, 0, 256 ) );
			} else {
				$spampreemail = false;
			}
		} else {
			$spampreemail = false;
		}
		$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

		// Spam White Controller.
		$spamtype                     = $spam_master_page;
		$spam_master_white_controller = new SpamMasterWhiteController();
		$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
		if ( ! empty( $is_spamadmin ) ) {
			$itis = true;
		}

		// Spam White Controller.
		$spamtype                     = $spam_master_page;
		$spam_master_white_controller = new SpamMasterWhiteController();
		$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
		if ( ! empty( $is_white ) ) {
			$itis = true;
		}

		// Spam Buffer Controller.
		$spam_master_buffer_controller = new SpamMasterBufferController();
		$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
		if ( ! empty( $is_buffer ) ) {
			// phpcs:ignore WordPress.WP.I18n.NonSingularStringLiteralText
			throw new Exception( __( '<strong>SPAM MASTER</strong> ' . $spam_master_message . '' ) );
		}

		// Spam Registration Controller.
		$spam_master_registration_controller = new SpamMasterRegistrationController();
		$is_register                         = $spam_master_registration_controller->spammasterregister( $is_collected['remote_ip'], $blog_threat_email, $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page );
		if ( $is_register ) {
			// phpcs:ignore WordPress.WP.I18n.NonSingularStringLiteralText
			throw new Exception( __( '<strong>SPAM MASTER</strong> ' . $spam_master_message . '' ) );
		}
		// end func.
		return $errors;
	}
	add_action( 'woocommerce_process_registration_errors', 'spam_master_validate_woo_extra_validate_fields', 10, 4 );
	// end valid.
}

